@@ -8,6 +8,7 @@
 """
 
 import sys
+import anyjson
 
 if sys.version_info >= (3, ):
     from urllib.parse import urljoin
@@ -15,17 +16,10 @@ elif sys.version_info >= (2, ):
     from urlparse import urljoin
 
 def get_wt():
-    if sys.version_info[0] == 3 and sys.version_info[1] == 2:
-        return 'json'
-    else:
-        return 'python'
+    return 'json'
 
 def parse_response(content):
-    if sys.version_info[0] == 3 and sys.version_info[1] == 2:
-        import json
-        return json.loads(content.decode('utf-8'))
-    else:
-        return eval(content)
+    return anyjson.loads(content.decode('utf-8'))
 
 def compat_args(query):
     for (key, value) in query.items():
